/* ************************************************************************** */
/*                                       _____           _                    */
/*  libp7/server.h                      |_   _|__  _   _| |__   ___ _   _     */
/*  | Project: libp7                      | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2017/01/04 15:02:44                               |___/     */
/*                                                                            */
/* ************************************************************************** */
#ifndef LIBP7_SERVER_H
# define LIBP7_SERVER_H

/*	A P7 server is basically a calculator. */
/* ************************************************************************** */
/*  Server information                                                        */
/* ************************************************************************** */
/* A version ("xx.xx.xx" + type) */
typedef struct {
	unsigned int major;
	unsigned int minor;
	unsigned int rev;
	char type[9];
} p7_version_t;

/* The protocol version format ("x.xx") */
typedef struct {
	unsigned int major;
	unsigned int minor;
} p7_protocolversion_t;

/* Main structure */
typedef struct {
	/* main information */
	char product_id[17], username[17], hwid[9], cpuid[17];
	p7_protocolversion_t protocol_version;

	/* preprogrammed ROM info */
	int preprog_rom_wiped;
	p7uint_t preprog_rom_capacity;
	p7_version_t preprog_rom_version;

	/* flash ROM and RAM info */
	p7uint_t flash_rom_capacity, ram_capacity;

	/* bootcode info */
	int bootcode_wiped;
	p7_version_t bootcode_version;
	p7uint_t bootcode_offset, bootcode_size;

	/* OS information */
	int os_wiped;
	p7_version_t os_version;
	p7uint_t os_offset, os_size;
} p7_server_t;

/* Functions */
typedef struct {
	int (*fls_mkdir)(const char *dirname, const char *devname);
} p7_server_functions_t;

/* Main libp7 function */
int p7_serve(p7_handle_t *handle, p7_server_t *info,
	p7_server_functions_t *callbacks);

#endif /* LIBP7_SERVER_H */
