/* ************************************************************************** */
/*                                       _____           _                    */
/*  handle/stream.c                     |_   _|__  _   _| |__   ___ _   _     */
/*  | Project: libp7                      | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2017/01/04 15:01:48                               |___/     */
/*                                                                            */
/* ************************************************************************** */
#include <libp7/internals.h>
#include <errno.h>
#include <string.h>
#include <unistd.h>

/**
 *	p7_read:
 *	Receive raw data via a P7 Stream.
 *
 *	@arg	stream		the P7 stream.
 *	@arg	dest		the data destination.
 *	@arg	size		the data size.
 *	@arg	timeout		the timeout in milliseconds.
 *	@return				the read bytes count.
 */

int p7_read(p7_stream_t *stream, void *dest, size_t size, unsigned int timeout)
{
	return ((*stream->_read)(stream->_cookie,
		(unsigned char*)dest, size, timeout));
}

/**
 *	p7_write:
 *	Send raw data via a P7 Stream.
 *
 *	@arg	stream		the P7 stream.
 *	@arg	data		the data.
 *	@arg	size		the data size.
 *	@return				the write bytes count.
 */

int p7_write(p7_stream_t *stream, const void *data, size_t size)
{
	return ((*stream->_write)(stream->_cookie,
		(const unsigned char*)data, size));
}
