/* ************************************************************************** */
/*                                       _____           _                    */
/*  protocol/backup_casiowin_entry.c    |_   _|__  _   _| |__   ___ _   _     */
/*  | Project: libp7                      | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2017/01/06 12:19:57                               |___/     */
/*                                                                            */
/* ************************************************************************** */
#include <libp7/internals.h>
#include <string.h>

/**
 *	p7_backup_casiowin_entry:
 *	Backup the CASIOWIN entry.
 *
 *	@arg	handle		the libp7 handle
 *	@arg	entry		the entry to fill (0x80 bytes).
 *	@return				the error code (0 if ok)
 */

int p7_backup_casiowin_entry(p7_handle_t *handle, p7_casiowin_entry_t *entry)
{
	int err;

	/* make checks */
	chk_handle(handle);
	chk_active(handle);

	/* send command packet */
	log_info("sending command");
	if ((err = p7_send_cmdbak_reqcwe(handle))) {
		log_fatal("couldn't send command/get response");
		return (err);
	} else if (response.type != p7_pt_ack) {
		log_fatal("received an invalid answer");
		return (p7_error_unknown);
	}

	/* send the roleswap */
	log_info("sending the roleswap");
	if ((err = p7_send_roleswp(handle))) {
		log_fatal("couldn't send roleswap");
		return (err);
	} else if (response.type != p7_pt_cmd || response.code != 0x53) {
		log_fatal("didn't receive correct command");
		return (p7_error_unknown);
	}

	/* get the data */
	err = p7_get_databuf(handle, entry, sizeof(p7_casiowin_entry_t), 0, NULL);

	/* returning the error */
	return (err);
}
