/* ************************************************************************** */
/*                                       _____           _                    */
/*  protocol/server.c                   |_   _|__  _   _| |__   ___ _   _     */
/*  | Project: libp7                      | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2017/01/04 15:02:36                               |___/     */
/*                                                                            */
/* ************************************************************************** */
#include <libp7/internals.h>

/**
 *	p7_serve:
 *	Initialize a server.
 *
 *	@arg	handle		the libp7 handle.
 *	@arg	info		the server information.
 *	@arg	callbacks	the server callbacks.
 *	@return				the error code.
 */

int p7_serve(p7_handle_t *handle, p7_server_t *info,
	p7_server_functions_t *callbacks)
{
	int err;
	(void)callbacks;
	/* make checks */
	chk_handle(handle);
	chk_passive(handle);

	/* initial receive */
	const p7_packet_t *resp = p7_get_response(handle);
	if ((err = p7_recv(handle, 0)))
		return (err);

	/* main loop */
	while (1) {
		/* check command packet */
		if (resp->type != p7_pt_cmd) {
			p7_send_err(handle, p7_err_other);
			continue ;
		}

		/* check if it is a known command */
		if (resp->code == 0x01)
			p7_send_eack(handle, info);
		else
			p7_send_err(handle, p7_err_other);
	}
}
