/* ************************************************************************** */
/*                                       _____           _                    */
/*  utils/checkusb.c                    |_   _|__  _   _| |__   ___ _   _     */
/*  | Project: libp7                      | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2017/01/04 15:01:48                               |___/     */
/*                                                                            */
/* ************************************************************************** */
#include <libp7/internals.h>

typedef unsigned int usb_code_t[2];
static usb_code_t usb_codes[] = {
	/* direct USB connexion */
	{0x07cf, 0x6101},

	/* Util-Pocket cable (some FTDI chip) */
	{0x0611, 0x0230},

	/* Official CASIO cable */
	{0x0bda, 0x5606},

	{}
};

/**
 *	_p7_check_usb:
 *	Check if the USB is an appropriate USB device for P7 communication.
 *
 *	@arg	idVendor	Vendor ID.
 *	@arg	idProduct	Product ID.
 *	@return				if it is appropriate.
 */

int _p7_check_usb(unsigned int idVendor, unsigned int idProduct)
{
	for (int i = 0; usb_codes[i][0]; i++)
		if (idVendor == usb_codes[i][0] && idProduct == usb_codes[i][1])
			return (1);
	return (0);
}
